@@ -35,18 +35,14 @@
 #endif // HAVE_LIBPOPT
 
 #include <stdlib.h>
-#if HAVE_STDINT_H
-#include <stdint.h>
-#endif
+#include <inttypes.h>
 #include <stdio.h>
 #include <time.h>
-#if !defined(__OpenBSD__)
 #if HAVE_ENDIAN_H
 #include <endian.h>
 #elif HAVE_MACHINE_ENDIAN_H
 #include <machine/endian.h>
 #endif
-#endif  /* OpenBSD */
 
 /* please tell me these are defined somewhere standard??? */
 #if defined(__OpenBSD__)  /* HAVE_SYS_PARAM_H */
@@ -69,7 +65,12 @@
 #endif
 
 // For now assume ARCH_X86 means GCC with hints.
-#define HAVE_GCC ARCH_X86
+#ifdef ARCH_X86
+#define HAVE_GCC 1
+#endif
+#ifdef ARCH_X86_64
+#define HAVE_GCC 1
+#endif
 //#define HAVE_GCC 0
 
 #if HAVE_GCC
@@ -126,7 +127,7 @@
 #define DV_FSC_0         (0)
 #define DV_FSC_1         (1)
 
-#if ARCH_X86
+#if ARCH_X86 || ARCH_X86_64
 #define DV_WEIGHT_BIAS	 6
 #else
 #define DV_WEIGHT_BIAS	 0
@@ -142,10 +143,6 @@
 #define DV_QUALITY_BEST       (DV_QUALITY_COLOR | DV_QUALITY_AC_2)
 #define DV_QUALITY_FASTEST     0     /* Monochrome, DC coeffs only */
 
-static const int header_size = 80 * 52; // upto first audio AAUX AS
-static const int frame_size_525_60 = 10 * 150 * 80;
-static const int frame_size_625_50 = 12 * 150 * 80;
-
 typedef enum color_space_e { 
   e_dv_color_yuv, 
   e_dv_color_rgb, 
@@ -518,6 +515,8 @@ typedef struct {
 
 #if ARCH_X86
 extern int dv_use_mmx;
+#elif ARCH_X86_64
+extern int dv_use_mmx;
 #endif
 
 #endif // DV_TYPES_H
